Consider Cox's PH model with covariate for interval-censored failure time data:
\(S(t|x) = S(t|x_0)^{\exp(\gamma^T(x-x_0))}\), where \(x_0\) satisfies \(\gamma^T(x-x_0)\ge 0\).
Let \(f(t|x)\) and \(F(t|x) = 1-S(t|x)\) be the density and cumulative distribution
functions of the event time given \(X = x\), respectively.
Then \(f(t|x_0)\) on \([0, \tau_n]\) can be approximated by
\(f_m(t|x_0, p) = \tau_n^{-1}\sum_{i=0}^m p_i\beta_{mi}(t/\tau_n)\),
where \(p_i \ge 0\), \(i = 0, \ldots, m\), \(\sum_{i=0}^mp_i = 1-p_{m+1}\),
\(\beta_{mi}(u)\) is the beta denity with shapes \(i+1\) and \(m-i+1\), and
\(\tau_n\) is the largest observed time, either uncensored time, or right endpoint of interval/left censored,
or left endpoint of right censored time. So we can approximate \(S(t|x_0)\) on \([0, \tau_n]\) by
\(S_m(t|x_0; p) = \sum_{i=0}^{m+1} p_i \bar B_{mi}(t/\tau_n)\), where
\(\bar B_{mi}(u)\), \(i = 0, \ldots, m\), is the beta survival function with shapes
\(i+1\) and \(m-i+1\), \(\bar B_{m,m+1}(t) = 1\), \(p_{m+1} = 1-\pi(x_0)\), and
\(\pi(x_0) = F(\tau_n|x_0)\). For data without right-censored time, \(p_{m+1} = 1-\pi(x_0) = 0\).
Response variable should be of the form cbind(l, u), where (l, u) is the interval
containing the event time. Data is uncensored if l = u, right censored
if u = Inf or u = NA, and left censored data if l = 0.
The associated covariate contains \(d\) columns. The baseline x0 should chosen so that
\(\gamma'(x-x_0)\) is nonnegative for all the observed \(x\) and
all \(\gamma\) in a neighborhood of its true value.
A missing initial value of g is imputed by ic_sp() of package icenReg.
The search for optimal degree m stops if either m1 is reached or the test
for change-point results in a p-value pval smaller than sig.level.
This process takes longer than maple.ph to select an optimal degree.