Wrapping all codemable fit of regression models in one function. Using maximum approximate Bernstein/Beta likelihood estimation to fit semiparametric regression models: Cox ph model, proportional odds(po) model, accelerated failure time model, and so on.
mable.reg(
formula,
data,
model = c("ph", "aft"),
M,
g = NULL,
pi0 = NULL,
tau = Inf,
x0 = NULL,
eta = 1,
controls = mable.ctrl(),
progress = TRUE
)A 'mable_reg' class object
regression formula. Response must be of the form cbind(l, u). See 'Details'.
a dataset
the model to fit. Current options are "ph"
(Cox PH) or "aft" (accelerated failure time model)
a vector (m0, m1) specifies the set of consective integers as candidate degrees
an initial guess of the regression coefficients
Initial guess of \(\pi(x_0) = F(\tau_n|x_0)\). Without right censored data, pi0 = 1. See 'Details'.
right endpoint of support \([0, \tau)\) must be greater than or equal to the maximum observed time
a working baseline covariate. See 'Details'.
the given positive value of \(\eta\). Used when model="po".
Object of class mable.ctrl() specifying iteration limit
and other control options. Default is mable.ctrl.
if TRUE a text progressbar is displayed
Zhong Guan <zguan@iusb.edu>
For "ph" model a missing initial guess of the regression coefficients
g is obtained by ic_sp() of package icenReg. For "aft" model a
missing g is imputed by the rank estimate aftsrr() of package aftgee
for right-censored data. For general interval censored observations, we keep the
right-censored but replace the finite interval with its midpoint and fit the data by
aftsrr() as a right-censored data.
mable.aft, mable.ph